@@ -91,7 +91,12 @@ DEFAULTS_SETTINGS = {
             'TOKEN': 'X1GOUqQcLipgwyhVYMPfagGIFqgbDHlF',
             'EncodingAESKey': 'uLVsTEJU6M20Ks1h2Bc9Rh4Y2FGG5IFrLcEhOjtmdqy'
         },
-        'redis_client': 'redis://127.0.0.1:6379/0'
+        'redis_client': 'redis://127.0.0.1:6379/0',
+        'login': {
+            'consumers': 'bluedot_rest_framework.wechat.login.consumers.WechatLoginConsumer',
+            'routing': 'bluedot_rest_framework.wechat.login.routing.websocket_urlpatterns',
+
+        }
     },
     'UTILS': {
         'AES': {
